@@ -6,6 +6,7 @@ d <- Read("Employee")
 
 ## ----labels-----------------------------------------------------------------------------------------------------------
 l <- rd("Employee_lbl")
+l
 
 ## ----fig.width=4.5, fig.height=4.5------------------------------------------------------------------------------------
 reg_brief(Salary ~ Years + Pre)
@@ -55,9 +56,10 @@ reg_brief(Salary ~ 1, plot_errors=TRUE)
 dd <- Read("Mach4")
 reg_brief(m10 ~ m02, data=dd)
 
-## ----fig.width=4, fig.height=4----------------------------------------------------------------------------------------
-Logit(Gender ~ Salary)
+## ---- fig.width=5, fig.height=4---------------------------------------------------------------------------------------
+d <- Read("BodyMeas")
+Logit(Gender ~ Hand)
 
-## ---------------------------------------------------------------------------------------------------------------------
-Logit(Gender ~ Years + Salary, prob_cut=c(.3, .5, .7))
+## ---- fig.width=5, fig.height=4---------------------------------------------------------------------------------------
+Logit(Gender ~ Hand, prob_cut=c(.3, .5, .7))
 
